@@ -20,7 +20,7 @@ Base utilities to build API operation managers and objects on top of.
 
 import copy
 
-import six.moves.urllib.parse as urlparse
+from urllib import parse as urlparse
 
 from zunclient.common.apiclient import base
 
